@@ -3,6 +3,7 @@ from .__agent__ import Agent, MultiAgent
 from .__tool__ import get_value_from_dict_by_multi_name, compute_by_string
 from .jieba_zh import analyse
 import re
+import random
 
 __RE_STAGE__ = "__RE_STAGE__"
 __QA_STAGE__ = "__QA_STAGE__"
@@ -73,7 +74,7 @@ class QAStage(Stage):
         return list(self.corpus.keys() if not self.refactor_questions else dict_corpus.keys()), dict_corpus
 
     def __decode_corpus__(self, worker_response, new_dict_corpus):
-        best_res_content = str(worker_response[0][0]).replace(" ", "")
+        best_res_content = str(worker_response[0][0])
         if self.refactor_questions:
             best_res_content = new_dict_corpus[best_res_content] if best_res_content in new_dict_corpus else '0'
         return best_res_content
